@@ -13,8 +13,8 @@
 (=> peroket disk-usage   :path "/tmp" :limit 0) ;; failure
 
 ;; check if :path file exists
-(=> mail  file-exists  :path "/bsd.rd" :desc "OpenBSD kernel /bsd.rd")
-(=> empty file-exists  :path "/non-existant-file" :try 3) ;; failure file not found
+(=> mail  check-file-exists  :path "/bsd.rd" :desc "OpenBSD kernel /bsd.rd")
+(=> empty check-file-exists  :path "/non-existant-file" :try 3) ;; failure file not found
 
 ;; check if :path file exists and has been updated since :limit minutes
 (=> empty file-updated :path "/var/log/messages" :limit 400)
