@@ -6,6 +6,7 @@
 
 ;; this is a comment
 ; this is also a comment
+(=> mail file-updated :path "/tmp/reed-alert" :limit 100)
 (=> mail disk-usage :path "/" :limit 90)
 
 (=> mail service :name "dovecot")
@@ -16,3 +17,4 @@
 (=> mail ping :host "bitreich.org" :desc "Ping Bitreich")
 (=> mail ping :host "openbsd.org"  :desc "Ping OpenBSD.org")
 (=> mail ssl-expiration :host "freenode.net" :seconds (* 7 24 60 60) :desc "SSL IRC Freenode")
+(=> mail write-to-file :path "/tmp/reed-alert")
