@@ -78,7 +78,7 @@
                                       (multiple-value-bind
                                             (second minute hour day month year)
                                           (get-decoded-time)
-                                        (format nil "~a/~a/~a ~a:~a:~a" year month day hour minute second))))
+                                        (format nil "~d-~2,'0d-~2,'0d ~2,'0d:~2,'0d:~2,'0d" year month day hour minute second))))
     command-string))
 
 (defmacro stop-if-error(&body body)
