@@ -1,5 +1,5 @@
 (create-probe
- file-exists
+ check-file-exists
  (let ((result (probe-file (getf params :path))))
    (if result
        t
